@@ -8,6 +8,7 @@ import Control.Exception
 import qualified Data.ByteString as S
 import Data.IORef (IORef, readIORef, writeIORef, newIORef)
 import Data.Typeable (Typeable)
+import Data.X509
 import Foreign.Ptr (Ptr)
 import System.Posix.Types (Fd)
 import qualified System.TimeManager as T
@@ -122,8 +123,16 @@ data Connection = Connection {
     , connWriteBuffer :: Buffer
     -- | The size of the write buffer.
     , connBufferSize  :: BufSize
+    -- | Is this connection HTTP/2?
+    , connHTTP2       :: IORef Bool
     }
 
+getConnHTTP2 :: Connection -> IO Bool
+getConnHTTP2 conn = readIORef (connHTTP2 conn)
+
+setConnHTTP2 :: Connection -> Bool -> IO ()
+setConnHTTP2 conn b = writeIORef (connHTTP2 conn) b
+
 ----------------------------------------------------------------
 
 data InternalInfo = InternalInfo {
@@ -171,6 +180,7 @@ data Transport = TCP -- ^ Plain channel: TCP
                  , tlsMinorVersion :: Int
                  , tlsNegotiatedProtocol :: Maybe ByteString -- ^ The result of Application Layer Protocol Negociation in RFC 7301
                  , tlsChiperID :: Word16
+                 , tlsClientCertificate :: Maybe CertificateChain
                  }  -- ^ Encrypted channel: TLS or SSL
 
 isTransportSecure :: Transport -> Bool
